package net.knarcraft.permissionsigns.command;

import net.knarcraft.permissionsigns.PermissionSigns;
import net.knarcraft.permissionsigns.container.PermissionSign;
import net.knarcraft.permissionsigns.formatting.StringFormatter;
import net.knarcraft.permissionsigns.formatting.TranslatableMessage;
import net.knarcraft.permissionsigns.formatting.Translator;
import org.bukkit.command.Command;
import org.bukkit.command.CommandExecutor;
import org.bukkit.command.CommandSender;
import org.bukkit.entity.Player;
import org.jetbrains.annotations.NotNull;

import java.util.List;

/**
 * The command used to create a new permission sign
 */
public class CreateCommand implements CommandExecutor {

    @Override
    public boolean onCommand(@NotNull CommandSender sender, @NotNull Command command, @NotNull String label, @NotNull String[] args) {
        // /ps create <name> <permission,permission> <cost> <duration> to create a new permission-sign
        //Name and permission(s) required, but duration and cost optional
        if (!(sender instanceof Player)) {
            sender.sendMessage(Translator.getTranslatedMessage(TranslatableMessage.COMMAND_PLAYER_ONLY));
            return false;
        }
        if (!sender.hasPermission("permissionsigns.admin.create")) {
            sender.sendMessage(StringFormatter.formatErrorMessage(Translator.getTranslatedMessage(TranslatableMessage.COMMAND_PERMISSION_DENIED)));
            return false;
        }
        if (args.length < 2) {
            sender.sendMessage(Translator.getTranslatedMessage(TranslatableMessage.MISSING_CREATION_INFO));
            return false;
        }

        PermissionSign newSign = parseSign(sender, args);
        if (newSign == null) {
            return false;
        }
        PermissionSigns.addSignCreationRequest((Player) sender, newSign);
        //TODO: Tell the user that the creation request has been created and that they need to right-click an empty 
        // sign within 60 seconds to register the permissions sign
        return true;
    }

    /**
     * Parses the permission sign given in user input
     *
     * @param sender <p>The sender that initiated the command</p>
     * @param args   <p>The given command arguments</p>
     * @return <p>The parsed sign, or null if it could not be parsed</p>
     */
    private PermissionSign parseSign(@NotNull CommandSender sender, @NotNull String[] args) {
        String name = args[0];
        String[] permissions = args[1].split(",");
        double cost;
        int duration;
        try {
            cost = Double.parseDouble(args[2]);
        } catch (NumberFormatException exception) {
            sender.sendMessage(Translator.getTranslatedMessage(TranslatableMessage.COST_INVALID_NUMBER));
            return null;
        }
        try {
            duration = Integer.parseInt(args[3]);
        } catch (NumberFormatException exception) {
            sender.sendMessage(Translator.getTranslatedMessage(TranslatableMessage.DURATION_INVALID_NUMBER));
            return null;
        }

        return new PermissionSign(name, List.of(permissions), duration, cost);
    }

}
