package net.knarcraft.permissionsigns.formatting;

/**
 * An enum representing all translatable messages
 */
public enum TranslatableMessage {

    /**
     * The prefix to display in messages
     */
    PREFIX,

    /**
     * The prefix to display on signs
     */
    SIGN_PREFIX,

    /**
     * The text to display as a permission sign's duration time unit
     */
    SIGN_TIME_UNIT,

    /**
     * The text to display on a permission sign that is entirely free
     */
    SIGN_COST_FREE,

    /**
     * The text to display on a permissions sign whose permissions never expire
     */
    SIGN_PERMANENT,

    /**
     * The error message to display if the given cost is not a valid number
     */
    COST_INVALID_NUMBER,

    /**
     * The error message to display if the given duration is not a valid number
     */
    DURATION_INVALID_NUMBER,

    /**
     * The error message to display if a player-only command is executed from the console
     */
    COMMAND_PLAYER_ONLY,

    /**
     * The error message to display if a player attempts to break a permission sign without the necessary permissions
     */
    PERMISSION_SIGN_DESTROY_DENY,

    /**
     * The error message to display if the user has not provided necessary information to create a permission sign
     */
    MISSING_CREATION_INFO,

    /**
     * The error message to be displayed when a player is denied from executing a command
     */
    COMMAND_PERMISSION_DENIED,

    /**
     * The message to be displayed when a player successfully destroys a permissions sign
     */
    PERMISSION_SIGN_REMOVED

}
